@@ -7,7 +7,7 @@
 | Acknowledgements    : Translated from VIPER Tools 2.0 (UC Santa Barbara, VIPER Lab).
 |                       Dar Roberts, Kerry Halligan, Philip Dennison, Kenneth Dudley, Ben Somers, Ann Crabbé
 |
-| This file is part of the QGIS Neural Network MLP Classifier plugin and mlp-image-classifier python package.
+| This file is part of the MESMA plugin and python package.
 |
 | This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 | License as published by the Free Software Foundation, either version 3 of the License, or any later version.
