@@ -5,7 +5,7 @@
 | Copyright           : © 2020 by Ann Crabbé (KU Leuven)
 | Email               : acrabbe.foss@gmail.com
 |
-| This file is part of the QGIS Neural Network MLP Classifier plugin and mlp-image-classifier python package.
+| This file is part of the MESMA plugin and python package.
 |
 | This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public
 | License as published by the Free Software Foundation, either version 3 of the License, or any later version.
@@ -25,7 +25,7 @@ author_doc = 'Ann Crabbé (KU Leuven)'
 author_email = 'acrabbe.foss@gmail.com'
 author_copyright = '© 2018 - 2020 by Ann Crabbé (KU Leuven)'
 short_version = '1.0'
-long_version = '1.0.6'
+long_version = '1.0.7'
 
 bitbucket_home = 'https://bitbucket.org/kul-reseco/mesma'
 bitbucket_src = 'https://bitbucket.org/kul-reseco/mesma/src'
